@@ -326,7 +326,11 @@ parser_styling_group.add_argument(
 parser_styling_group.add_argument(
     "--xkcd",
     action="store_true",
-    help="XKCD mode (Install 'Humor Sans' / 'XKCD Font' for best results)",
+    help="XKCD mode (Install 'Humor Sans' / 'XKCD Font' for best results). "
+    f"You can tweak the wigglyness via environment variables "
+    f"HLEDGER_PLOT_XKCD_SCALE (=1), "
+    f"HLEDGER_PLOT_XKCD_SCALE (=100) and "
+    f"HLEDGER_PLOT_XKCD_RANDOMNESS (=2).",
 )
 parser_styling_group.add_argument(
     "--drawstyle",
@@ -1110,8 +1114,34 @@ pip install windows-curses
     logger.debug(f"Sorting data")
     data = data.sort_index()
 
+    def sanitize_text(s):
+        return s
+
+    if args.xkcd:
+        if (
+            any(euro_cols := [col for col in data if "€" in col])
+            or any("€" in str(x) for x in hledger_cmdline_parts)
+            or "€" in str(args.title)
+        ) and not os.environ.get("HLEDGER_PLOT_PROTECT_EURO"):
+            euro_repl = "EUR"
+            logger.warning(
+                f"Replacing the € symbol in columns {euro_cols} and elsewhere with {euro_repl!r} "
+                f"as the Humor Sans font uses an unpleasant glyph for it. "
+                f"Set the HLEDGER_PLOT_PROTECT_EURO to something nonempty to skip this."
+            )
+
+            def sanitize_text(s):
+                return s.replace("€", euro_repl)
+
+    logger.debug(f"🧹 Sanitizing column names")
+    data = data.rename(columns={col: sanitize_text(col) for col in data})
+
     logger.info("📈  Plotting...")
-    with plt.xkcd() if args.xkcd else nothing():
+    with plt.xkcd(
+        scale=float(os.environ.get("HLEDGER_PLOT_XKCD_SCALE", 1)),
+        length=float(os.environ.get("HLEDGER_PLOT_XKCD_LENGTH", 100)),
+        randomness=float(os.environ.get("HLEDGER_PLOT_XKCD_RANDOMNESS", 2)),
+    ) if args.xkcd else nothing():
         fig, ax = plt.subplots(num=args.title)
         if args.barplot:
             logger.warning(
@@ -1180,11 +1210,11 @@ pip install windows-curses
                 )
 
         if args.title:
-            fig.suptitle(args.title)
-        ax.set_title(args.axtitle or " ".join(hledger_args))
+            fig.suptitle(sanitize_text(args.title))
+        ax.set_title(sanitize_text(args.axtitle or " ".join(hledger_args)))
         if args.groupby:
             ax.set_xlabel(f"days within period")
-        ax.set_ylabel(" ".join(f"[{c}]" for c in commodities))
+        ax.set_ylabel(" ".join(f"[{sanitize_text(c)}]" for c in commodities))
         ax.legend(ncols=math.ceil(len(ax.get_lines()) / 40))
 
         fig.tight_layout()
